@@ -24,7 +24,7 @@ import signal
 from qubesadmin import exc
 from qubesadmin import utils as admin_utils
 
-from PyQt5 import QtCore, QtWidgets, QtGui  # pylint: disable=import-error
+from PyQt5 import QtCore, QtWidgets, QtGui, Qt  # pylint: disable=import-error
 from . import ui_backupdlg  # pylint: disable=no-name-in-module
 from . import multiselectwidget
 
@@ -80,6 +80,10 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
 
         self.setupUi(self)
 
+        self.setWindowFlags(self.windowFlags() |
+                            Qt.Qt.WindowMaximizeButtonHint |
+                            Qt.Qt.WindowMinimizeButtonHint)
+
         self.progress_status.text = self.tr("Backup in progress...")
         self.dir_line_edit.setReadOnly(False)
 
@@ -99,6 +103,8 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
         # but completeChanged twice. Somehow.
         self.select_vms_widget.selectedChanged.connect(
             self.select_vms_page.completeChanged.emit)
+        self.select_vms_widget.selectedChanged.connect(
+            self.update_metadata_warning)
         self.passphrase_line_edit.textChanged.connect(
             self.backup_location_changed)
         self.passphrase_line_edit_verify.textChanged.connect(
@@ -152,6 +158,10 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
         self.save_passphrase_warning.setEnabled(save_profile and
                 self.save_passphrase_checkbox.isChecked())
 
+    def update_metadata_warning(self):
+        self.metadata_warning_label.setVisible(
+            self.select_vms_widget.available_list.count() > 0)
+
     def setup_application(self):
         self.qt_app.setApplicationName(self.tr("Qubes Backup VMs"))
         self.qt_app.setWindowIcon(QtGui.QIcon.fromTheme("qubes-manager"))
@@ -279,6 +289,7 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
 
         self.total_size_label.setText(
             admin_utils.size_to_human(self.total_size))
+        self.update_metadata_warning()
 
     def vms_added(self, items):
         for i in items:
