@@ -21,7 +21,9 @@
 # with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 #
+import shlex
 import subprocess
+import threading
 from datetime import datetime, timedelta
 from functools import partial
 from os import path
@@ -56,6 +58,14 @@ from . import common_threads
 from . import clone_vm
 
 
+def spawn_in_background(cmd: str | list[str]) -> None:
+    if isinstance(cmd, str):
+        cmd = shlex.split(cmd)
+    # pylint: disable=consider-using-with
+    p = subprocess.Popen(cmd)
+    threading.Thread(target=p.wait, daemon=True).start()
+
+
 class SearchBox(QLineEdit):
     def __init__(self, parent=None):
         super().__init__(parent)
@@ -203,6 +213,7 @@ class VmInfo():
         self.label = getattr(self.vm, 'label', None)
         self.klass = getattr(self.vm, 'klass', None)
         self.icon = getattr(vm, 'icon', 'appvm-black')
+        self.auto_cleanup = getattr(vm, 'auto_cleanup', False)
 
         self.state = {'power': "", 'outdated': ""}
         self.updateable = getattr(vm, 'updateable', False)
@@ -622,23 +633,14 @@ class StartVMThread(common_threads.QubesThread):
 
 
 # pylint: disable=too-few-public-methods
-class UpdateVMThread(common_threads.QubesThread):
+class UpdateVMsThread(common_threads.QubesThread):
     def run(self):
+        vm_names = self.vm
+
         try:
-            if self.vm.klass == 'AdminVM':
-                subprocess.check_call(
-                    ["/usr/bin/qubes-dom0-update", "--clean", "--gui"])
-            else:
-                if not manager_utils.is_running(self.vm, False):
-                    try:
-                        self.vm.start()
-                    except exc.QubesDaemonAccessError:
-                        # permission denied, let us hope for the best
-                        pass
-                self.vm.run_service("qubes.InstallUpdatesGUI",
-                                    user="root", wait=False)
-        except (OSError, subprocess.SubprocessError,
-                exc.QubesException) as ex:
+            subprocess.check_call(
+                ["/usr/bin/qubes-update-gui", "--targets", ",".join(vm_names)])
+        except subprocess.SubprocessError as ex:
             self.msg = (self.tr("Error on qube update!"), str(ex))
 
 
@@ -890,7 +892,8 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
                 netvm = self._get_default_netvm()
             else:
                 netvm = self.qubes_cache.get_vm(name=netvm_name)
-            if check_power and netvm.state['power'] != 'Running':
+                netvm = netvm.vm
+            if check_power and netvm and not netvm.is_running():
                 reply = QMessageBox.question(
                     self, self.tr("Qube Start Confirmation"),
                     self.tr("<br>Can not change netvm to a halted Qube.<br>"
@@ -899,7 +902,7 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
                     QMessageBox.Yes | QMessageBox.Cancel)
 
                 if reply == QMessageBox.Yes:
-                    self.start_vm(netvm.vm, True)
+                    self.start_vm(netvm, True)
                 else:
                     return
 
@@ -1249,7 +1252,8 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
                 self.network_menu.setEnabled(False)
             elif vm.klass == 'DispVM':
                 self.action_appmenus.setEnabled(False)
-                self.action_restartvm.setEnabled(False)
+                if vm.auto_cleanup:
+                    self.action_restartvm.setEnabled(False)
                 self.template_menu.setEnabled(False)
             elif vm.klass == 'TemplateVM':
                 self.template_menu.setEnabled(False)
@@ -1592,23 +1596,11 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_updatevm_triggered')
     def action_updatevm_triggered(self):
-        for vm_info in self.get_selected_vms():
-            vm = vm_info.vm
-            if not manager_utils.is_running(vm, True):
-                reply = QMessageBox.question(
-                    self, self.tr("Qube Update Confirmation"),
-                    self.tr(
-                        "<b>{0}</b>"
-                        "<br>The Qube has to be running to be updated."
-                        "<br>Do you want to start it?<br>").format(vm.name),
-                    QMessageBox.Yes | QMessageBox.Cancel)
-                if reply != QMessageBox.Yes:
-                    return
-
-            thread = UpdateVMThread(vm)
-            self.threads_list.append(thread)
-            thread.finished.connect(self.clear_threads)
-            thread.start()
+        vms = [vm_info.name for vm_info in self.get_selected_vms()]
+        thread = UpdateVMsThread(vms)
+        self.threads_list.append(thread)
+        thread.finished.connect(self.clear_threads)
+        thread.start()
 
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_run_command_in_vm_triggered')
@@ -1662,12 +1654,14 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_global_settings_triggered')
     def action_global_settings_triggered(self):  # pylint: disable=invalid-name
-        subprocess.check_call('qubes-global-config')
+        # pylint: disable=consider-using-with
+        spawn_in_background('qubes-global-config')
 
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_manage_templates_triggered')
     def action_manage_templates_triggered(self):
-        subprocess.check_call('qubes-template-manager')
+        # pylint: disable=consider-using-with
+        spawn_in_background('qubes-template-manager')
 
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_show_network_triggered')
