@@ -105,7 +105,8 @@ class QubeManagerTest(unittest.TestCase):
             self.assertEqual(name_item, vm.name,
                              "Incorrect VM name for {}".format(vm.name))
 
-        actual_vms = [vm.name for vm in self.qapp.domains]
+        actual_vms = [vm.name for vm in self.qapp.domains
+                      if not vm.features.get('internal', False)]
 
         self.assertEqual(len(vms_in_table), len(actual_vms),
                          "Incorrect number of VMs loaded")
@@ -368,22 +369,6 @@ class QubeManagerTest(unittest.TestCase):
         self._select_admin_vm()
         self.assertFalse(self.dialog.action_set_keyboard_layout.isEnabled())
 
-    @unittest.mock.patch("PyQt5.QtWidgets.QMessageBox.question",
-                         return_value=QtWidgets.QMessageBox.Yes)
-    def test_207_update_vm_not_running(self, _):
-        selected_vm = self._select_templatevm(running=False)
-        self.assertIsNotNone(selected_vm, "No valid template VM found")
-
-        widget = self.dialog.toolbar.widgetForAction(
-            self.dialog.action_updatevm)
-
-        with unittest.mock.patch('qubesmanager.qube_manager.UpdateVMThread') \
-                as mock_update:
-            QtTest.QTest.mouseClick(widget,
-                                    QtCore.Qt.LeftButton)
-            mock_update.assert_called_once_with(selected_vm)
-            mock_update().start.assert_called_once_with()
-
     def test_208_update_vm_admin(self):
         selected_vm = self._select_admin_vm()
         self.assertIsNotNone(selected_vm, "No valid admin VM found")
@@ -391,11 +376,11 @@ class QubeManagerTest(unittest.TestCase):
         widget = self.dialog.toolbar.widgetForAction(
             self.dialog.action_updatevm)
 
-        with unittest.mock.patch('qubesmanager.qube_manager.UpdateVMThread') \
+        with unittest.mock.patch('qubesmanager.qube_manager.UpdateVMsThread') \
                 as mock_update:
             QtTest.QTest.mouseClick(widget,
                                     QtCore.Qt.LeftButton)
-            mock_update.assert_called_once_with(selected_vm)
+            mock_update.assert_called_once_with([selected_vm.name])
             mock_update().start.assert_called_once_with()
 
     @unittest.mock.patch("PyQt5.QtWidgets.QInputDialog.getText",
@@ -576,26 +561,13 @@ class QubeManagerTest(unittest.TestCase):
                 self.dialog.clear_threads)
             mock_thread().start.assert_called_once_with()
 
-    @unittest.mock.patch('qubesmanager.qube_manager.UpdateVMThread')
+    @unittest.mock.patch('qubesmanager.qube_manager.UpdateVMsThread')
     def test_223_updatevm_running(self, mock_thread):
         selected_vm = self._select_non_admin_vm(running=True)
 
         self.dialog.action_updatevm.trigger()
 
-        mock_thread.assert_called_once_with(selected_vm)
-        mock_thread().finished.connect.assert_called_once_with(
-            self.dialog.clear_threads)
-        mock_thread().start.assert_called_once_with()
-
-    @unittest.mock.patch("PyQt5.QtWidgets.QMessageBox.question",
-                         return_value=QtWidgets.QMessageBox.Yes)
-    @unittest.mock.patch('qubesmanager.qube_manager.UpdateVMThread')
-    def test_224_updatevm_halted(self, mock_thread, _):
-        selected_vm = self._select_non_admin_vm(running=False)
-
-        self.dialog.action_updatevm.trigger()
-
-        mock_thread.assert_called_once_with(selected_vm)
+        mock_thread.assert_called_once_with([selected_vm.name])
         mock_thread().finished.connect.assert_called_once_with(
             self.dialog.clear_threads)
         mock_thread().start.assert_called_once_with()
@@ -621,16 +593,15 @@ class QubeManagerTest(unittest.TestCase):
             self.assertEqual(mock_kill.call_count, 0,
                              "Ignored Cancel on kill VM")
 
-    @unittest.mock.patch('qubesmanager.global_settings.GlobalSettingsWindow')
-    def test_226_global_settings(self, mock_settings):
+    @unittest.mock.patch('subprocess.Popen')
+    def test_226_global_settings(self, mock_subprocess):
         self._select_non_admin_vm()
         self.dialog.action_global_settings.trigger()
-        self.assertEqual(mock_settings.call_count, 1,
-                         "Global Settings not opened")
+        mock_subprocess.assert_called_once_with(['qubes-global-config'])
 
         self._select_admin_vm()
         self.dialog.action_global_settings.trigger()
-        self.assertEqual(mock_settings.call_count, 2,
+        self.assertEqual(mock_subprocess.call_count, 2,
                          "Global Settings not opened for the second time")
 
     @unittest.mock.patch('qubesmanager.backup.BackupVMsWindow')
@@ -661,12 +632,12 @@ class QubeManagerTest(unittest.TestCase):
             self.dialog.action_exit.trigger()
             mock_close.assert_called_once_with()
 
-    @unittest.mock.patch('subprocess.check_call')
+    @unittest.mock.patch('subprocess.Popen')
     def test_231_template_manager(self, mock_subprocess):
         self.assertTrue(self.dialog.action_manage_templates.isEnabled())
 
         self.dialog.action_manage_templates.trigger()
-        mock_subprocess.assert_called_once_with('qubes-template-manager')
+        mock_subprocess.assert_called_once_with(['qubes-template-manager'])
 
     @unittest.mock.patch('qubesmanager.clone_vm.CloneVMDlg')
     def test_232_clonevm(self, mock_clone):
@@ -708,7 +679,8 @@ class QubeManagerTest(unittest.TestCase):
 
         # clear search
         self.dialog.searchbox.setText("")
-        expected_number = len([vm for vm in self.qapp.domains])
+        expected_number = len([vm for vm in self.qapp.domains
+                               if not vm.features.get('internal', False)])
         actual_number = self._count_visible_table_rows()
         self.assertEqual(expected_number, actual_number,
                          "Incorrect number of vms shown for cleared search box")
@@ -736,7 +708,8 @@ class QubeManagerTest(unittest.TestCase):
         self.assertEqual(self.dialog.searchbox.text(), "",
                          "Escape failed to clear searchbox")
 
-        expected_number = len([vm for vm in self.qapp.domains])
+        expected_number = len([vm for vm in self.qapp.domains
+                               if not vm.features.get('internal', False)])
         actual_number = self._count_visible_table_rows()
         self.assertEqual(expected_number, actual_number,
                          "Incorrect number of vms shown for cleared search box")
@@ -1034,7 +1007,8 @@ class QubeManagerTest(unittest.TestCase):
         # table contains the correct vms
         vms_in_table = self._create_set_of_current_vms()
 
-        vms_in_system = set([vm.name for vm in self.qapp.domains])
+        vms_in_system = set([vm.name for vm in self.qapp.domains
+                             if not vm.features.get('internal', False)])
 
         self.assertEqual(vms_in_table, vms_in_system, "Table not updated "
                                                       "correctly after add")
@@ -1607,62 +1581,37 @@ class QubeManagerThreadTest(unittest.TestCase):
 
     @unittest.mock.patch('subprocess.check_call')
     def test_20_update_vm_thread_dom0(self, check_call):
-        vm = unittest.mock.Mock(spec=['klass'])
+        vm = unittest.mock.Mock(spec=['klass', 'name'])
         vm.klass = 'AdminVM'
-        thread = qube_manager.UpdateVMThread(vm)
+        vm.name = 'dom0'
+        thread = qube_manager.UpdateVMsThread([vm.name])
         thread.run()
 
         check_call.assert_called_once_with(
-            ["/usr/bin/qubes-dom0-update", "--clean", "--gui"])
+            ["/usr/bin/qubes-update-gui", "--targets", "dom0"])
 
-    @unittest.mock.patch('subprocess.call')
+    @unittest.mock.patch('subprocess.check_call')
     def test_21_update_vm_thread_running(self, mock_call):
         vm = unittest.mock.Mock(
-            spec=['klass', 'is_running', 'run_service_for_stdio', 'run_service'],
+            spec=['klass', 'is_running', 'run_service_for_stdio',
+                  'run_service', 'name'],
             **{'is_running.return_value': True})
 
         vm.klass = 'AppVM'
+        vm.name = 'testvm'
         vm.run_service_for_stdio.return_value = (b'changed=no\n', None)
 
-        thread = qube_manager.UpdateVMThread(vm)
+        thread = qube_manager.UpdateVMsThread([vm.name])
 
         thread.run()
 
-        vm.run_service.assert_called_once_with(
-            "qubes.InstallUpdatesGUI", user="root", wait=False)
+        mock_call.assert_called_once_with(
+            ["/usr/bin/qubes-update-gui", "--targets", "testvm"])
 
-        self.assertEqual(mock_call.call_count, 0)
-
-    @unittest.mock.patch('subprocess.call')
-    def test_22_update_vm_thread_not_running(self, mock_call):
-        vm = unittest.mock.Mock(
-            spec=['klass', 'is_running', 'run_service_for_stdio',
-                  'run_service', 'start', 'name'],
-            **{'is_running.return_value': False})
-
-        vm.klass = 'AppVM'
-        vm.run_service_for_stdio.return_value = (b'changed=yes\n', None)
-
-        thread = qube_manager.UpdateVMThread(vm)
-        thread.run()
-
-        vm.start.assert_called_once_with()
-
-        vm.run_service.assert_called_once_with(
-            "qubes.InstallUpdatesGUI", user="root", wait=False)
-
-        self.assertEqual(mock_call.call_count, 0)
-
-    @unittest.mock.patch('builtins.open')
     @unittest.mock.patch('subprocess.check_call')
-    def test_23_update_vm_thread_error(self, *_args):
-        vm = unittest.mock.Mock(
-            spec=['klass', 'is_running'],
-            **{'is_running.side_effect': ChildProcessError})
-
-        vm.klass = 'AppVM'
-
-        thread = qube_manager.UpdateVMThread(vm)
+    def test_23_update_vm_thread_error(self, mock_call):
+        mock_call.side_effect = subprocess.SubprocessError
+        thread = qube_manager.UpdateVMsThread(['test'])
         thread.run()
 
         self.assertIsNotNone(thread.msg)
